@@ -56,7 +56,10 @@ typedef unsigned long long int  uint64_t;
 #ifndef ENABLE_STAND_ALONE
 #  include <stdarg.h>
 #else
+#ifndef _VA_LIST_
+#define _VA_LIST_
 typedef char *va_list;
+#endif
 #undef va_arg
 #undef va_end
 #undef va_start
@@ -147,7 +150,7 @@ typedef struct aal_hash_table aal_hash_table_t;
 typedef errno_t (*foreach_func_t) (void *, void *);
 
 /* These types is used for keeping the block number and block count value. They
-   are needed to be increase source code maintainability.
+   are needed to increase source code maintainability.
 
    For instance, there is some function:
 
@@ -280,33 +283,37 @@ typedef aal_exception_option_t (*aal_exception_handler_t) (aal_exception_t *ex);
 typedef struct aal_gauge aal_gauge_t;
 
 enum aal_gauge_state {
-	GAUGE_STARTED,
-	GAUGE_RUNNING,
-	GAUGE_PAUSED,
-	GAUGE_DONE,
+	GS_START,
+	GS_ACTIVE,
+	GS_PAUSE,
+	GS_RESUME,
+	GS_DONE,
+	GS_LAST
 };
 
 typedef enum aal_gauge_state aal_gauge_state_t;
 
 typedef void (*aal_gauge_handler_t)(aal_gauge_t *);
 
-struct aal_gauge_type {
-	uint32_t type;
-	aal_gauge_handler_t handler;
+struct aal_gauge_time {
+	/* Time in sec, millisec. */
+	uint64_t sec, misec;
+	/* Interval in milliseconds gauge should be shown once. */
+	uint64_t gap;
 };
 
-typedef struct aal_gauge_type aal_gauge_type_t;
-
-#define MAX_GAUGES 10
+typedef struct aal_gauge_time aal_gauge_time_t;
 
 struct aal_gauge {
-	void *data;
-    
-	uint32_t type;
-	uint32_t value;
-	char name[256];
-
+	aal_gauge_handler_t handler;
 	aal_gauge_state_t state;
+	char label[80];
+	
+	/* Prepare the value if needed. */
+	aal_gauge_handler_t value_func;
+	aal_gauge_time_t time;
+	int64_t value;
+	void *data;
 };
 
 /* Stream types. */
