@@ -16,8 +16,8 @@ typedef int64_t (*aal_numeric_func_t) (const char *, int64_t,
 
 typedef int (*aal_check_alpha_func_t) (char *, void *);
 
-typedef char *(*aal_alpha_func_t) (const char *, char *,
-				   aal_check_alpha_func_t, void *);
+typedef void (*aal_alpha_func_t) (const char *, char *,
+				  aal_check_alpha_func_t, void *);
 
 extern void aal_ui_set_numeric_handler(aal_numeric_func_t func);
 extern aal_numeric_func_t aal_ui_get_numeric_handler(void);
@@ -29,9 +29,9 @@ extern int64_t aal_ui_get_numeric(int64_t defvalue,
 extern void aal_ui_set_alpha_handler(aal_alpha_func_t func);
 extern aal_alpha_func_t aal_ui_get_alpha_handler(void);
 
-extern char *aal_ui_get_alpha(char *defvalue, 
-			      aal_check_alpha_func_t check_func,
-			      void *, const char *format, ...);
+extern void aal_ui_get_alpha(char *defvalue, 
+			     aal_check_alpha_func_t check_func,
+			     void *, const char *format, ...);
 #endif
 
 #endif
